==> camel-k-model-v1-6.5.0-sources.jar: io/fabric8/camelk/v1/PodSpecTemplateFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodSpecTemplateFluentImpl<A extends PodSpecTemplateFluent<A>> extends BaseFluent<A> implements PodSpecTemplateFluent<A>{
  public PodSpecTemplateFluentImpl() {
  }
  public PodSpecTemplateFluentImpl(PodSpecTemplate instance) {
    this.withSpec(instance.getSpec()); 
  }
  private PodSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodSpecTemplateFluent.SpecNested<A> withNewSpec() {
    return new PodSpecTemplateFluentImpl.SpecNestedImpl();
  }
  public PodSpecTemplateFluent.SpecNested<A> withNewSpecLike(PodSpec item) {
    return new PodSpecTemplateFluentImpl.SpecNestedImpl(item);
  }
  public PodSpecTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodSpecTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodSpecBuilder().build());
  }
  public PodSpecTemplateFluent.SpecNested<A> editOrNewSpecLike(PodSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodSpecTemplateFluentImpl that = (PodSpecTemplateFluentImpl) o;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends PodSpecFluentImpl<PodSpecTemplateFluent.SpecNested<N>> implements PodSpecTemplateFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodSpec item) {
      this.builder = new PodSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodSpecBuilder(this);
    }
    PodSpecBuilder builder;
    public N and() {
      return (N) PodSpecTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/PodSpecTemplateFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodSpecTemplateFluentImpl<A extends PodSpecTemplateFluent<A>> extends BaseFluent<A> implements PodSpecTemplateFluent<A>{
  public PodSpecTemplateFluentImpl() {
  }
  public PodSpecTemplateFluentImpl(PodSpecTemplate instance) {
    if (instance != null) {
      this.withSpec(instance.getSpec());
    }
  }
  private PodSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PodSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PodSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PodSpecTemplateFluentImpl.SpecNested<A> withNewSpec() {
    return new PodSpecTemplateFluentImpl.SpecNestedImpl();
  }
  public PodSpecTemplateFluentImpl.SpecNested<A> withNewSpecLike(PodSpec item) {
    return new PodSpecTemplateFluentImpl.SpecNestedImpl(item);
  }
  public PodSpecTemplateFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PodSpecTemplateFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PodSpecBuilder().build());
  }
  public PodSpecTemplateFluentImpl.SpecNested<A> editOrNewSpecLike(PodSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSpecTemplateFluentImpl that = (PodSpecTemplateFluentImpl) o;
    if (!java.util.Objects.equals(spec, that.spec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class SpecNestedImpl<N> extends PodSpecFluentImpl<PodSpecTemplateFluentImpl.SpecNested<N>> implements PodSpecTemplateFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PodSpec item) {
      this.builder = new PodSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PodSpecBuilder(this);
    }
    PodSpecBuilder builder;
    public N and() {
      return (N) PodSpecTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
